/*------------------------------------------------------------------*-

   Switch_Wait.C (v1.00)

  ------------------------------------------------------------------

   Simple library for debouncing a switch input.

   NOTE: Duration of function is highly variable!

   COPYRIGHT
   ---------

   This code is associated with the book:

   EMBEDDED C by Michael J. Pont 
   [Pearson Education, 2002: ISBN: 0-201-79523-X].

   This code is copyright (c) 2001 by Michael J. Pont.
 
   See book for copyright details and other information.

-*------------------------------------------------------------------*/

#include "Main.H"
#include "Port.H"

#include "Switch_wait.h"
#include "Delay_loop.h"

/*------------------------------------------------------------------*-

  SWITCH_Init()

  Initialisation function for the switch library.

-*------------------------------------------------------------------*/
void SWITCH_Init(void)
   {
   Switch_pin = 1; // Use this pin for input
   }

/*------------------------------------------------------------------*-
  
  SWITCH_Get_Input()

  Reads and debounces a mechanical switch as follows:

  1. If switch is not pressed, return SWITCH_NOT_PRESSED.

  2. If switch is pressed, wait for DEBOUNCE_PERIOD (in ms).
     a. If switch is not pressed, return SWITCH_NOT_PRESSED. 
     b. If switch is pressed, wait (indefinitely) for
        switch to be released, then return SWITCH_PRESSED

  See Switch_Wait.H for details of return values.
  
-*------------------------------------------------------------------*/
bit SWITCH_Get_Input(const tByte DEBOUNCE_PERIOD)
   {
   bit Return_value = SWITCH_NOT_PRESSED;

   if (Switch_pin == 0)
      {
      // Switch is pressed
      
      // Debounce - just wait...
      DELAY_LOOP_Wait(DEBOUNCE_PERIOD);

      // Check switch again
      if (Switch_pin == 0)
         {
         // Wait until the switch is released.
         while (Switch_pin == 0);
         Return_value = SWITCH_PRESSED;
         }
      }
   
   // Now (finally) return switch value
   return Return_value;
   }

/*------------------------------------------------------------------*-
  ---- END OF FILE -------------------------------------------------
-*------------------------------------------------------------------*/
